# WSCls

Simple terminal based websocket terminal client

![Demo](/data/demo.svg)


## Installation

```bash
pip install wscls
```

## Run

```
wscls
```

## Hotkeys

- Ctrl + r - Send message(on text area only)
- Ctrl + c - Quit
